@@ -26,7 +26,14 @@ from cryptography.hazmat.backends import default_backend
 from cryptography.hazmat.primitives import hashes, serialization
 from cryptography.hazmat.primitives.asymmetric import padding, utils
 
-from snowflake.connector.errorcode import ER_INVALID_OCSP_RESPONSE, ER_INVALID_OCSP_RESPONSE_CODE
+from snowflake.connector.errorcode import (
+    ER_OCSP_RESPONSE_ATTACHED_CERT_EXPIRED,
+    ER_OCSP_RESPONSE_ATTACHED_CERT_INVALID,
+    ER_OCSP_RESPONSE_CERT_STATUS_INVALID,
+    ER_OCSP_RESPONSE_INVALID_SIGNATURE,
+    ER_OCSP_RESPONSE_LOAD_FAILURE,
+    ER_OCSP_RESPONSE_STATUS_UNSUCCESSFUL,
+)
 from snowflake.connector.errors import RevocationCheckError
 from snowflake.connector.ocsp_snowflake import SnowflakeOCSP
 from snowflake.connector.ssd_internal_keys import ret_wildcard_hkey
@@ -186,7 +193,7 @@ class SnowflakeOCSPAsn1Crypto(SnowflakeOCSP):
         if res['response_status'].native != 'successful':
             raise RevocationCheckError(
                 msg="Invalid Status: {}".format(res['response_status'].native),
-                errno=ER_INVALID_OCSP_RESPONSE)
+                errno=ER_OCSP_RESPONSE_STATUS_UNSUCCESSFUL)
 
         basic_ocsp_response = res.basic_ocsp_response
         if basic_ocsp_response['certs'].native:
@@ -233,17 +240,18 @@ class SnowflakeOCSPAsn1Crypto(SnowflakeOCSP):
             if self.test_mode is not None:
                 ocsp_load_failure = getenv("SF_TEST_OCSP_FORCE_BAD_OCSP_RESPONSE")
                 if ocsp_load_failure is not None:
-                    raise RevocationCheckError("Force fail")
+                    raise RevocationCheckError("Force fail",
+                                               errno=ER_OCSP_RESPONSE_LOAD_FAILURE)
         except Exception:
             raise RevocationCheckError(
                 msg='Invalid OCSP Response',
-                errno=ER_INVALID_OCSP_RESPONSE
+                errno=ER_OCSP_RESPONSE_LOAD_FAILURE
             )
 
         if res['response_status'].native != 'successful':
             raise RevocationCheckError(
                 msg="Invalid Status: {}".format(res['response_status'].native),
-                errno=ER_INVALID_OCSP_RESPONSE)
+                errno=ER_OCSP_RESPONSE_STATUS_UNSUCCESSFUL)
 
         basic_ocsp_response = res.basic_ocsp_response
         if basic_ocsp_response['certs'].native:
@@ -257,22 +265,25 @@ class SnowflakeOCSPAsn1Crypto(SnowflakeOCSP):
 
             cur_time = datetime.now(timezone.utc)
 
-            """
-            Signature verification should happen before any kind of
-            validation
-            """
-            self.verify_signature(
-                ocsp_cert.hash_algo,
-                ocsp_cert.signature,
-                issuer,
-                ocsp_cert['tbs_certificate'])
-
+            try:
+                """
+                Signature verification should happen before any kind of
+                validation
+                """
+                self.verify_signature(
+                    ocsp_cert.hash_algo,
+                    ocsp_cert.signature,
+                    issuer,
+                    ocsp_cert['tbs_certificate'])
+            except RevocationCheckError as rce:
+                raise RevocationCheckError(msg=rce.msg,
+                                           errno=ER_OCSP_RESPONSE_ATTACHED_CERT_INVALID)
             cert_valid, debug_msg = self.check_cert_time_validity(cur_time, ocsp_cert)
 
             if not cert_valid:
                 raise RevocationCheckError(
                     msg=debug_msg,
-                    errno=ER_INVALID_OCSP_RESPONSE_CODE)
+                    errno=ER_OCSP_RESPONSE_ATTACHED_CERT_EXPIRED)
 
         else:
             logger.debug("Certificate is NOT attached in Basic OCSP Response. "
@@ -282,11 +293,15 @@ class SnowflakeOCSPAsn1Crypto(SnowflakeOCSP):
         tbs_response_data = basic_ocsp_response['tbs_response_data']
 
         logger.debug("Verifying the OCSP response is signed by the issuer.")
-        self.verify_signature(
-            basic_ocsp_response['signature_algorithm'].hash_algo,
-            basic_ocsp_response['signature'].native,
-            ocsp_cert,
-            tbs_response_data)
+        try:
+            self.verify_signature(
+                basic_ocsp_response['signature_algorithm'].hash_algo,
+                basic_ocsp_response['signature'].native,
+                ocsp_cert,
+                tbs_response_data)
+        except RevocationCheckError as rce:
+            raise RevocationCheckError(msg=rce.msg,
+                                       errno=ER_OCSP_RESPONSE_INVALID_SIGNATURE)
 
         single_response = tbs_response_data['responses'][0]
         cert_status = single_response['cert_status'].name
@@ -313,7 +328,7 @@ class SnowflakeOCSPAsn1Crypto(SnowflakeOCSP):
                     format(cert_status)
                 raise RevocationCheckError(
                     msg=debug_msg,
-                    errno=ER_INVALID_OCSP_RESPONSE_CODE
+                    errno=ER_OCSP_RESPONSE_CERT_STATUS_INVALID
                 )
         except RevocationCheckError as op_er:
             debug_msg = "{} Consider running curl -o ocsp.der {}".\
@@ -337,8 +352,7 @@ class SnowflakeOCSPAsn1Crypto(SnowflakeOCSP):
             digest.update(data.dump())
             if not signer.verify(digest, signature):
                 raise RevocationCheckError(
-                    msg="Failed to verify the signature",
-                    errno=ER_INVALID_OCSP_RESPONSE)
+                    msg="Failed to verify the signature")
 
         else:
             backend = default_backend()
@@ -362,8 +376,7 @@ class SnowflakeOCSPAsn1Crypto(SnowflakeOCSP):
                 )
             except InvalidSignature:
                 raise RevocationCheckError(
-                    msg="Failed to verify the signature",
-                    errno=ER_INVALID_OCSP_RESPONSE)
+                    msg="Failed to verify the signature")
 
     def extract_certificate_chain(self, connection):
         """Gets certificate chain and extract the key info from OpenSSL connection."""
